@@ -8,7 +8,7 @@ describe 'manila::db::mysql' do
   end
 
   let :facts do
-    {:osfamily => 'Debian'}
+    @default_facts.merge({:osfamily => 'Debian'})
   end
 
   let :pre_condition do
