@@ -23,7 +23,7 @@ describe 'manila::share::glusterfs' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'glusterfs share driver'
@@ -31,7 +31,7 @@ describe 'manila::share::glusterfs' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'glusterfs share driver'
