@@ -1,7 +1,11 @@
 require 'spec_helper'
 describe 'manila' do
   let :req_params do
-    {:rabbit_password => 'guest', :sql_connection => 'mysql+pymysql://user:password@host/database'}
+    {
+      :rabbit_password => 'guest',
+      :sql_connection  => 'mysql+pymysql://user:password@host/database',
+      :purge_config    => false,
+    }
   end
 
   let :facts do
@@ -16,11 +20,23 @@ describe 'manila' do
     it { is_expected.to contain_class('manila::logging') }
     it { is_expected.to contain_class('manila::params') }
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('manila_config').with({
+        :purge => false
+      })
+    end
+
     it 'should contain default config' do
       is_expected.to contain_manila_config('DEFAULT/rpc_backend').with(
         :value => 'rabbit'
       )
-      is_expected.to contain_manila_config('DEFAULT/notification_driver').with(
+      is_expected.to contain_manila_config('DEFAULT/transport_url').with(
+        :value => '<SERVICE DEFAULT>'
+      )
+      is_expected.to contain_manila_config('oslo_messaging_notifications/transport_url').with(
+        :value => '<SERVICE DEFAULT>'
+      )
+      is_expected.to contain_manila_config('oslo_messaging_notifications/driver').with(
         :value => 'messaging'
       )
       is_expected.to contain_manila_config('DEFAULT/control_exchange').with(
@@ -31,24 +47,27 @@ describe 'manila' do
         :secret => true
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_host').with(
-        :value => '127.0.0.1'
+        :value => '<SERVICE DEFAULT>'
+      )
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/amqp_durable_queues').with(
+        :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_port').with(
-        :value => '5672'
+        :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_hosts').with(
-        :value => '127.0.0.1:5672'
+        :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_ha_queues').with(
-        :value => false
+        :value => '<SERVICE DEFAULT>'
+      )
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_use_ssl').with(
+        :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_virtual_host').with(
-        :value => '/'
+        :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_userid').with(
-        :value => 'guest'
-      )
-      is_expected.to contain_manila_config('DEFAULT/verbose').with(
         :value => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_manila_config('DEFAULT/debug').with(
@@ -79,8 +98,10 @@ describe 'manila' do
     end
 
     it 'should contain many' do
-      is_expected.to_not contain_manila_config('oslo_messaging_rabbit/rabbit_host')
-      is_expected.to_not contain_manila_config('oslo_messaging_rabbit/rabbit_port')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_host').with(
+        :value => '<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_port').with(
+        :value => '<SERVICE DEFAULT>')
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_hosts').with(
         :value => 'rabbit1:5672,rabbit2:5672'
       )
@@ -96,13 +117,15 @@ describe 'manila' do
     end
 
     it 'should contain many' do
-      is_expected.to_not contain_manila_config('oslo_messaging_rabbit/rabbit_host')
-      is_expected.to_not contain_manila_config('oslo_messaging_rabbit/rabbit_port')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_host').with(
+        :value => '<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_port').with(
+        :value => '<SERVICE DEFAULT>')
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_hosts').with(
         :value => 'rabbit1:5672'
       )
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_ha_queues').with(
-        :value => false
+        :value => '<SERVICE DEFAULT>'
       )
     end
   end
@@ -148,33 +171,35 @@ describe 'manila' do
 
     it do
       is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
     end
   end
 
   describe 'with SSL disabled' do
     let :params do
       req_params.merge!({
-        :rabbit_use_ssl     => false,
+        :rabbit_use_ssl     => true,
         :kombu_ssl_version  => 'TLSv1'
       })
     end
 
     it do
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_manila_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
     end
   end
 
   describe 'with amqp_durable_queues disabled' do
     let :params do
-      req_params
+      req_params.merge({
+        :amqp_durable_queues => false,
+      })
     end
 
     it { is_expected.to contain_manila_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false) }
@@ -248,16 +273,29 @@ describe 'manila' do
     it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
   end
 
+  describe 'with transport_url entries' do
+
+    let :params do
+      {
+        :default_transport_url      => 'rabbit://rabbit_user:password@localhost:5673',
+        :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+      }
+    end
+
+    it { is_expected.to contain_manila_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673') }
+    it { is_expected.to contain_manila_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673') }
+  end
+
   describe 'with amqp rpc supplied' do
 
     let :params do
       {
         :sql_connection         => 'mysql+pymysql://user:password@host/database',
-        :rpc_backend            => 'zmq',
+        :rpc_backend            => 'amqp',
       }
     end
 
-    it { is_expected.to contain_manila_config('DEFAULT/rpc_backend').with_value('zmq') }
+    it { is_expected.to contain_manila_config('DEFAULT/rpc_backend').with_value('amqp') }
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/server_request_prefix').with_value('exclusive') }
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/broadcast_prefix').with_value('broadcast') }
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/group_request_prefix').with_value('unicast') }
@@ -265,58 +303,15 @@ describe 'manila' do
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/idle_timeout').with_value('0') }
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/trace').with_value(false) }
     it { is_expected.to contain_manila_config('oslo_messaging_amqp/allow_insecure_clients').with_value(false) }
-  end
-
-  describe 'with amqp SSL disable' do
-    let :params do
-      {
-        :rabbit_password => 'guest',
-      }
-    end
-
-    it do
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_password').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_ca_file').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_cert_file').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_file').with_ensure('absent')
-    end
-  end
-
-  describe 'with amqp SSL enabled' do
-    let :params do
-      {
-        :rabbit_password       => 'guest',
-        :amqp_ssl_ca_file      => '/path/to/ssl/ca/certs',
-        :amqp_ssl_cert_file    => '/path/to/ssl/cert/file',
-        :amqp_ssl_key_file     => '/path/to/ssl/keyfile',
-        :amqp_ssl_key_password => 'guest',
-      }
-    end
-
-    it do
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_password').with_value('guest')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/ssl/keyfile')
-    end
-  end
-
-  describe 'with amqp SSL enabled without amqp_ssl_key_password' do
-    let :params do
-      {
-        :rabbit_password        => 'guest',
-        :amqp_ssl_ca_file      => '/path/to/ssl/ca/certs',
-        :amqp_ssl_cert_file    => '/path/to/ssl/cert/file',
-        :amqp_ssl_key_file     => '/path/to/ssl/keyfile',
-      }
-    end
-
-    it do
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_password').with_ensure('absent')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/ssl/keyfile')
-    end
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')}
+    it { is_expected.to contain_manila_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')}
   end
 
 end
