@@ -27,8 +27,8 @@ describe 'manila::backend::generic' do
       is_expected.to contain_manila_config('hippo/share_driver').with_value(
         'manila.share.drivers.generic.GenericShareDriver')
       is_expected.to contain_manila_config('hippo/share_helpers').with_value(
-        'CIFS=manila.share.drivers.generic.CIFSHelper,'\
-        'NFS=manila.share.drivers.generic.NFSHelper')
+        'CIFS=manila.share.drivers.helpers.CIFSHelperIPAccess,'\
+        'NFS=manila.share.drivers.helpers.NFSHelper')
       params.each_pair do |config,value|
         is_expected.to contain_manila_config("hippo/#{config}").with_value( value )
       end
