@@ -26,7 +26,7 @@ describe 'manila::backend::glusterfs' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'glusterfs share driver'
@@ -34,7 +34,7 @@ describe 'manila::backend::glusterfs' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'glusterfs share driver'
