@@ -28,7 +28,7 @@ describe 'manila::backend::glusternative' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'glusternative volume driver'
@@ -36,7 +36,7 @@ describe 'manila::backend::glusternative' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'glusternative volume driver'
